@@ -498,28 +498,28 @@ class ModelSerializer(Serializer):
         self.m2m_data = {}
         self.related_data = {}
 
+        # Reverse fk relations
+        for (obj, model) in self.opts.model._meta.get_all_related_objects_with_model():
+            field_name = obj.field.related_query_name()
+            if field_name in attrs:
+                self.related_data[field_name] = attrs.pop(field_name)
+
+        # Reverse m2m relations
+        for (obj, model) in self.opts.model._meta.get_all_related_m2m_objects_with_model():
+            field_name = obj.field.related_query_name()
+            if field_name in attrs:
+                self.m2m_data[field_name] = attrs.pop(field_name)
+
+        # Forward m2m relations
+        for field in self.opts.model._meta.many_to_many:
+            if field.name in attrs:
+                self.m2m_data[field.name] = attrs.pop(field.name)
+
         if instance is not None:
             for key, val in attrs.items():
                 setattr(instance, key, val)
 
         else:
-            # Reverse fk relations
-            for (obj, model) in self.opts.model._meta.get_all_related_objects_with_model():
-                field_name = obj.field.related_query_name()
-                if field_name in attrs:
-                    self.related_data[field_name] = attrs.pop(field_name)
-
-            # Reverse m2m relations
-            for (obj, model) in self.opts.model._meta.get_all_related_m2m_objects_with_model():
-                field_name = obj.field.related_query_name()
-                if field_name in attrs:
-                    self.m2m_data[field_name] = attrs.pop(field_name)
-
-            # Forward m2m relations
-            for field in self.opts.model._meta.many_to_many:
-                if field.name in attrs:
-                    self.m2m_data[field.name] = attrs.pop(field.name)
-
             instance = self.opts.model(**attrs)
 
         try:
@@ -530,13 +530,13 @@ class ModelSerializer(Serializer):
 
         return instance
 
-    def save(self, save_m2m=True):
+    def save(self):
         """
         Save the deserialized object and return it.
         """
         self.object.save()
 
-        if getattr(self, 'm2m_data', None) and save_m2m:
+        if getattr(self, 'm2m_data', None):
             for accessor_name, object_list in self.m2m_data.items():
                 setattr(self.object, accessor_name, object_list)
             self.m2m_data = {}
